@@ -15,7 +15,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -74,7 +74,8 @@ sub reset {
 # Serialize.
 sub serialize {
 	my $self = shift;
-	return join "\n", $self->_serialize('.', $self->{'config'});
+	return join $INPUT_RECORD_SEPARATOR,
+		$self->_serialize($self->{'config'});
 }
 
 # Check structure.
@@ -129,12 +130,11 @@ sub _parse {
 
 # Serialize.
 sub _serialize {
-	my ($self, $sep, $config_hr) = @_;
+	my ($self, $config_hr) = @_;
 	my @ret;
 	foreach my $key (sort keys %{$config_hr}) {
 		if (ref $config_hr->{$key} eq 'HASH') {
-			my @subkey = $self->_serialize('.',
-				$config_hr->{$key});
+			my @subkey = $self->_serialize($config_hr->{$key});
 			foreach my $subkey (@subkey) {
 				push @ret, $key.'.'.$subkey;
 			}
@@ -221,12 +221,12 @@ Serialize 'config' hash to output.
  Mine:
          Bad 'config' parameter.
 
- From Config::Utils::conflict():
-         Conflict in '%s'.
-
  From Class::Utils::set_params():
          Unknown parameter '%s'.
 
+ From Config::Utils::conflict():
+         Conflict in '%s'.
+
 =head1 EXAMPLE1
 
  # Pragmas.
@@ -305,6 +305,6 @@ BSD license.
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
